==> nextcloud-12.0.7.tar.bz2: nextcloud/apps/firstrunwizard/l10n/sk.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Sprievodca prvým spustením",
    "Add your profile information! For example your email is needed to reset your password." : "Pridajte svoje informácie o profile! Váš e-mail je napríklad potrebný na obnovenie hesla.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Pridajte svoje informácie o profile! Nastavte si profilový obrázok a celé meno pre jednoduchšie rozpoznanie naprieč všetkými funkciami.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Pridajte svoje informácie o profile! Nastavte si celé meno pre jednoduchšie rozpoznanie všetkými funkciami.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Pridajte svoje informácie o profile! Nastavte si profilový obrázok pre jednoduchšie rozpoznanie naprieč všetkými funkciami.",
    "Get the apps to sync your files" : "Získať aplikácie na synchronizáciu vašich súborov",
    "Desktop client" : "Desktopový klient",
    "Android app" : "Android aplikácia",
    "iOS app" : "iOS aplikácia",
    "Connect your calendar" : "Pripojte svoj ​​kalendár",
    "Connect your contacts" : "Pripojte svoje kontakty",
    "Access files via WebDAV" : "Pristupovať k súborom cez WebDAV",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Pristupujte a zdieľajte svoje súbory, kalendáre, kontakty, e-mail a pod. z akéhokoľvek zariadenia, podľa vašich podmienok",
    "Connect your desktop apps to %s" : "Pripojiť svoju desktopovú aplikáciu na %s",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Viac informácií nájdete v <a target=\"_blank\" href=\"%s\">dokumentácii</a> a na našej <a target=\"_blank\" href=\"%s\">webstránke</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Ak sa vám páči Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\">odporučte ho svojim priateľom</a> a <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">prispejte späť</a>.",
    "Connect your Calendar" : "Pripojte svoj ​​kalendár",
    "Connect your Contacts" : "Pripojte svoje kontakty",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Ak chcete podporiť projekt {contributeopen}zapojte sa do vývoja{linkclose}, alebo {contributeopen}dajte o nás vedieť{linkclose}!",
    "Show First Run Wizard again" : "Znovu zobraziť sprievodcu prvým spustením"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-14.0.4.tar.bz2: nextcloud/apps/firstrunwizard/l10n/sk.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Sprievodca prvým spustením",
    "Add your profile information! For example your email is needed to reset your password." : "Pridajte svoje informácie o profile! Váš e-mail je napríklad potrebný na obnovenie hesla.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Pridajte svoje informácie o profile! Nastavte si profilový obrázok a celé meno pre jednoduchšie rozpoznanie naprieč všetkými funkciami.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Pridajte svoje informácie o profile! Nastavte si celé meno pre jednoduchšie rozpoznanie všetkými funkciami.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Pridajte svoje informácie o profile! Nastavte si profilový obrázok pre jednoduchšie rozpoznanie naprieč všetkými funkciami.",
    "About" : "O aplikácii",
    "Extend your cloud" : "Rozšírte svoj cloud",
    "Communication with Nextcloud Talk" : "Komunikácia cez Nextcloud Talk",
    "Browse the app store" : "Prehliadajte obchod aplikácií",
    "Stay in sync" : "Zostane synchronizovaní",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud vám dáva prístup k vašim súborom kdekoľvek ste.",
    "Get the apps to sync your files" : "Získať aplikácie na synchronizáciu vašich súborov",
    "Desktop client" : "Desktopový klient",
    "Android app" : "Android aplikácia",
    "iOS app" : "iOS aplikácia",
    "Connect your desktop apps to %s" : "Pripojiť svoju desktopovú aplikáciu na %s",
    "Connect your calendar" : "Pripojte svoj ​​kalendár",
    "Connect your contacts" : "Pripojte svoje kontakty",
    "Access files via WebDAV" : "Pristupovať k súborom cez WebDAV",
    "Get help" : "Získajte pomoc",
    "Get more information" : "Získajte viac informácií",
    "The Nextcloud documentation for home users:" : "Nextcloud dokumentácia pre domácich používateľov:",
    "User manual" : "Používateľský manuál",
    "Admin manual" : "Administrátorský manuál",
    "Developer manual" : "Manuál pre vývojára",
    "You can also ask for help in our community support channels:" : "Môžete požiadať o pomoc v našich komunitných kanáloch:",
    "the Nextcloud forums" : "Nextcloud fórum",
    "the Nextcloud IRC chat channel on freenode.net" : "Nextcloud IRC kanál na freenode.net",
    "Start contributing" : "Začnite prispievať",
    "Become part of the Community" : "Staňte sa členom komunity",
    "Enterprise support" : "Enterprise podpora",
    "Get enterprise support" : "Získajte enterprise podporu",
    "A safe home for all your data" : "Bezpečný domov pre všetky vaše dáta",
    "Open Standards and Interoperability" : "Otvorené štandardy a interoperabilita",
    "100%% Open Source & community-focused" : "100%% Open Source so zameraním na komunitu",
    "Learn more about %s" : "Dozvedieť sa viac o %s",
    "Connect other apps to %s" : "Pripojte iné aplikácie do %s",
    "Previous" : "Predchádzajúce",
    "Next" : "Ďalšie",
    "Start using Nextcloud" : "Začnite používať Nextcloud",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Pristupujte a zdieľajte svoje súbory, kalendáre, kontakty, e-mail a pod. z akéhokoľvek zariadenia, podľa vašich podmienok",
    "Connect your Calendar" : "Pripojte svoj ​​kalendár",
    "Connect your Contacts" : "Pripojte svoje kontakty",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Viac informácií nájdete v <a target=\"_blank\" href=\"%s\">dokumentácii</a> a na našej <a target=\"_blank\" href=\"%s\">webstránke</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Ak sa vám páči Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\">odporučte ho svojim priateľom</a> a <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">prispejte späť</a>.",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Ak chcete podporiť projekt {contributeopen}zapojte sa do vývoja{linkclose}, alebo {contributeopen}dajte o nás vedieť{linkclose}!",
    "Show First Run Wizard again" : "Znovu zobraziť sprievodcu prvým spustením"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
